# Welcome to the `nomad-neb-workflows` documentation

A NOMAD plugin containing the section definitions and normalizer functions of a standard Nudged Elastic Band (NEB) workflow.

## Introduction

This neb-workflow plugin lets you link individual calculations that belong to one NEB calculations and automatically extracts reaction and activation energies. NEB calculations are an important tool in computational catalysis and battery research to estimate reaction or migration barriers.



<div markdown="block" class="home-grid">
<div markdown="block">

### Tutorial

TODO

- [Tutorial](tutorial/tutorial.md)

</div>
<div markdown="block">

### How-to guides

How-to guides provide step-by-step instructions for a wide range of tasks, with the overarching topics:

- [Install this plugin](how_to/install_this_plugin.md)
- [Use this plugin](how_to/use_this_plugin.md)
- [Contribute to this plugin](how_to/contribute_to_this_plugin.md)
- [Contribute to the documentation](how_to/contribute_to_the_documentation.md)

</div>

<div markdown="block">

### Explanation

The explanation [section](explanation/explanation.md) provides background knowledge on this plugin.

</div>
<div markdown="block">

### Reference

The reference [section](reference/references.md) includes all CLI commands and arguments, all configuration options,
the possible schema annotations and their arguments, and a glossary of used terms.

</div>
</div>
